@@ -1,6 +1,6 @@
 package Bundle::InterchangeKitchenSink;
 
-$VERSION = '1.05';
+$VERSION = '1.06';
 
 1;
 
@@ -28,6 +28,10 @@ URI::URL
 
 HTML::Tagset
 
+HTML::Entities
+
+HTML::Parser
+
 Bundle::LWP
 
 IO::Scalar
